## 20250619
- 增加上传文件和下载文件的命令工具
- ~~原本不想引入 tqdm 的, 但发现 tqdm 的进度条显示比原来的好看多了, 所以还是引入了~~  引入 tqdm 库, 使上传和下载的进度条更统一

## 20250520

- 使用`dotenv`库读取配置文件, 方便使用
- 实现目录的上传与下载, 删除
- 百度云盘秒到123


## 20250517

- 初次提交, 可能存在bug. 使用中慢慢发现bug.




